@@ -306,7 +306,7 @@ def showGraph(self,  QtGui):
         x=i/Xscale
 #        x=i/Xscale+1
 #        paint.drawLine(x, data.Ysize-peak-1-15, x, data.Ysize-1-15)  #draw yellow movement bar
-        h=min(peak*data.Yscale,  data.Ysize-17) #cut off if higher than graph border
+        h=min(peak*data.Yscale/2,  data.Ysize-17) #cut off if higher than graph border
         paint.drawLine(x, data.Ysize-h-1-15, x, data.Ysize-1-15)  #draw yellow movement bar
         
         if(peak>data.Trigger):
@@ -435,12 +435,12 @@ def showGraph(self,  QtGui):
     if(records.statusID=="OK"):       
         if(data.run==False):  #show trigger level stored in record
             paint.setPen(QtGui.QColor("gray"))
-            y=(data.Ysize-(records.Trigger*data.Yscale))-2
+            y=(data.Ysize-(records.Trigger*data.Yscale/2))-2
             paint.drawLine(1, y-15, 781, y-15)  #Trigger line
             paint.drawText(760, y-17, str(records.Trigger)) #Trigger level
 #            paint.drawText(5, 15, str(data.Yscale)) #Y scale
         paint.setPen(QtGui.QColor("white"))
-        y=(data.Ysize-(data.Trigger*data.Yscale))-2
+        y=(data.Ysize-(data.Trigger*data.Yscale/2))-2
         paint.drawLine(1, y-15, 781, y-15)  #Trigger line
         paint.drawText(760, y-17, str(data.Trigger)) #Trigger level
 #        paint.drawText(5, 15, str(data.Yscale)) #Y scale
