@@ -209,6 +209,7 @@ def InitMeasurement():
         data.interval=10 #Fast mode for testing
         data.Xscale=0 #set to max zoom level
     
+#    print "#################### USE MAXIMUM SPEED FOR DEBUGGING!!!!!!!!!!!"
 #    data.interval=1 #Debugging
     
     #change to offline mode and silent profile if requested
@@ -1091,6 +1092,7 @@ class frmConfigWindow(QMainWindow):
         
         config.set('main', 'user', str(data.user.encode( "utf-8" )))      
         config.set('main', 'DelayStartTime', str(data.DelayStartTime))      
+        config.set('main', 'Yscale', str(data.Yscale))      
         
         ConfigWindow.close()
         StartWindow.show()
